@@ -4,8 +4,8 @@
 
 ;; Author: John Wiegley <jwiegley@gmail.com>
 ;; Created: 18 Jun 2012
-;; Version: 1.9.3
-;; Package-Requires: ((cl-lib "0.5") (nadvice "0.3"))
+;; Version: 1.9.5
+;; Package-Requires: ((emacs "24.3"))
 
 ;; Keywords: async
 ;; X-URL: https://github.com/jwiegley/emacs-async
@@ -87,12 +87,12 @@ is returned unmodified."
         (t object)))
 
 (defun async-inject-variables
-  (include-regexp &optional predicate exclude-regexp noprops)
+    (include-regexp &optional predicate exclude-regexp noprops)
   "Return a `setq' form that replicates part of the calling environment.
 
 It sets the value for every variable matching INCLUDE-REGEXP and
 also PREDICATE.  It will not perform injection for any variable
-matching EXCLUDE-REGEXP (if present) or representing a syntax-table
+matching EXCLUDE-REGEXP (if present) or representing a `syntax-table'
 i.e. ending by \"-syntax-table\".
 When NOPROPS is non nil it tries to strip out text properties of each
 variable's value with `async-variables-noprops-function'.
@@ -191,9 +191,9 @@ It is intended to be used as follows:
 
 (defun async--insert-sexp (sexp)
   (let (print-level
-	print-length
-	(print-escape-nonascii t)
-	(print-circle t))
+        print-length
+        (print-escape-nonascii t)
+        (print-circle t))
     (prin1 sexp (current-buffer))
     ;; Just in case the string we're sending might contain EOF
     (encode-coding-region (point-min) (point-max) 'utf-8-auto)
@@ -209,22 +209,22 @@ It is intended to be used as follows:
     (process-send-region process (point-min) (point-max))))
 
 (defun async-batch-invoke ()
-  "Called from the child Emacs process' command-line."
+  "Called from the child Emacs process' command line."
   ;; Make sure 'message' and 'prin1' encode stuff in UTF-8, as parent
   ;; process expects.
   (let ((coding-system-for-write 'utf-8-auto))
     (setq async-in-child-emacs t
-	  debug-on-error async-debug)
+          debug-on-error async-debug)
     (if debug-on-error
-	(prin1 (funcall
-		(async--receive-sexp (unless async-send-over-pipe
-				       command-line-args-left))))
+        (prin1 (funcall
+                (async--receive-sexp (unless async-send-over-pipe
+                                       command-line-args-left))))
       (condition-case err
-	  (prin1 (funcall
-		  (async--receive-sexp (unless async-send-over-pipe
-					 command-line-args-left))))
-	(error
-	 (prin1 (list 'async-signal err)))))))
+          (prin1 (funcall
+                  (async--receive-sexp (unless async-send-over-pipe
+                                         command-line-args-left))))
+        (error
+         (prin1 (list 'async-signal err)))))))
 
 (defun async-ready (future)
   "Query a FUTURE to see if it is ready.
@@ -235,7 +235,7 @@ I.e., if no blocking would result from a call to `async-get' on that FUTURE."
          (if (buffer-live-p buf)
              (with-current-buffer buf
                async-callback-value-set)
-             t))))
+           t))))
 
 (defun async-wait (future)
   "Wait for FUTURE to become ready."
@@ -254,7 +254,7 @@ its FINISH-FUNC is nil."
          #'identity async-callback-value (current-buffer))))))
 
 (defun async-message-p (value)
-  "Return true of VALUE is an async.el message packet."
+  "Return non-nil of VALUE is an async.el message packet."
   (and (listp value)
        (plist-get value :async-message)))
 
@@ -272,7 +272,7 @@ its FINISH-FUNC is nil."
 
 ;;;###autoload
 (defun async-start-process (name program finish-func &rest program-args)
-  "Start the executable PROGRAM asynchronously.  See `async-start'.
+  "Start the executable PROGRAM asynchronously named NAME.  See `async-start'.
 PROGRAM is passed PROGRAM-ARGS, calling FINISH-FUNC with the
 process object when done.  If FINISH-FUNC is nil, the future
 object will return the process object when the program is
@@ -343,8 +343,8 @@ passed to FINISH-FUNC).  Call `async-get' on such a future always
 returns nil.  It can still be useful, however, as an argument to
 `async-ready' or `async-wait'."
   (let ((sexp start-func)
-	;; Subordinate Emacs will send text encoded in UTF-8.
-	(coding-system-for-read 'utf-8-auto))
+        ;; Subordinate Emacs will send text encoded in UTF-8.
+        (coding-system-for-read 'utf-8-auto))
     (setq async--procvar
           (async-start-process
            "emacs" (file-truename
@@ -358,9 +358,9 @@ returns nil.  It can still be useful, however, as an argument to
            "-batch" "-f" "async-batch-invoke"
            (if async-send-over-pipe
                "<none>"
-               (with-temp-buffer
-                 (async--insert-sexp (list 'quote sexp))
-                 (buffer-string)))))
+             (with-temp-buffer
+               (async--insert-sexp (list 'quote sexp))
+               (buffer-string)))))
     (if async-send-over-pipe
         (async--transmit-sexp async--procvar (list 'quote sexp)))
     async--procvar))
@@ -375,7 +375,7 @@ returns nil.  It can still be useful, however, as an argument to
       (setq res (funcall fn res
                          (if (listp binding)
                              binding
-                             (list binding)))))
+                           (list binding)))))
     res))
 
 (defmacro async-let (bindings &rest forms)
